@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 
 import stretch_body.arm as arm
+import stretch_body.hello_utils as hu
+hu.print_stretch_re_use()
 
 import argparse
 parser=argparse.ArgumentParser(description='Calibrate arm position by moving to one/both hardstops')
